## arjunarth Library 

[![arjunarth - Version](https://img.shields.io/pypi/v/arjunarth?style=round)](https://pypi.org/project/arjunarth)    
[![PyPI - Downloads](https://img.shields.io/pypi/dm/arjunarth?label=DOWNLOADS&style=round)](https://pypi.org/project/arjunarth)    
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/TeamKillerX/arjunarth/graphs/commit-activity)
[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/TeamKillerX/arjunarth)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://makeapullrequest.com)


* <b>DarkWeb Userbot Pyrogram</b>

## Disclaimer
```
️                       ⚠️ WARNING FOR YOU ️ ️⚠️
   arjunarth is used to help your account activities on Telegram
   We are not responsible for what you misuse in this repository
   !  Be careful when using this repository!
   If one of the members misuses this repository, we are forced to ban you
   Never ever abuse this repository
``` 

## Installing
```
pip3 install arjunarth
```

## Example [EVAL]
```python
from arjunarth.carbon import make_carbon

write = "i'am Arjunarth"
carbon = await make_carbon(write)
await c.send_photo(m.chat.id, carbon)
```


